/*
**
**   This code is a part of the ETSI Technical Specification 06.77,
**   Digital cellular telecommunications system (Phase 2+);
**   Minimum Performance Requirements for Noise Suppresser Application to the AMR Speech Encoder
**
*/

/*
       =============================================================
       COPYRIGHT NOTE: This source code, and all of its derivations,
       is subject to the "ITU-T SOFTWARE TOOLS' GENERAL PUBLIC LICENSE". 
	   Please have it  read  in    the  distribution  disk,   or  in  
	   the  ITU-T Recommendation G.191 on "SOFTWARE TOOLS FOR SPEECH AND  
	   AUDIO CODING STANDARDS".
       =============================================================
*/


/*
**
**   OBJECTIVE MEASURES FOR CHARACTERISATION OF AMR/NS SOLUTIONS
**
**
**   MODULE:         main.h, global and main level constant data definitions,
**                     data type definitions and function prototypes
**   ORIGINAL BY:    
**      Beghdad Ayad     Nokia Research Center    Finland
**      Erkki Paajanen   Nokia Research Center    Finland
**   DATE:           19/Jan/2001
**   RELEASE:        1.00
**   FUNCTIONS:      none
**   PROTOTYPES:     no functions
**   NOTES:          The delay definitions (AMR_DELAY, AMRNS_DELAY) below have to be adjusted
**                   for the studied AMR/NS solution to correspond the algorithmic delay in
**                   samples of the AMR speech codec without NS and the AMR speech codec
**                   together with the NS solution, respectively.
**                   Also, the data structures (NoiseType) and path definitions in this file
**                   need to be tailored to cover the speech database and the AMR speech
**                   codec and AMR/NS solution programs to be used in the subjective testing
**                   of the AMR/NS solution under study to enable the computation
**                   of the objective measures over the same material in car and
**                   street noise conditions. The example data provided the original
**                   version of this file describe the relevant conditions of the
**                   AMR/NS selection phase subjective tests.
**
**
**   MODIFICATION HISTORY:
**      15/Jun/00 v0.90 Release for inclusion in ETSI TS 06.77.   <erkki.paajanen@nokia.com>
**      19/Jan/01 v1.00 CR release: Inclusion of "ITU General Public License" terms.
**                                                                <erkki.paajanen@nokia.com>
**
**
*/


/*
** Copyright (c) 1999-2001 Nokia Corporation
*/


#ifndef _MAIN_
#define _MAIN_

/*---------------------------------------------------------------------------
 *                              Constants
 *--------------------------------------------------------------------------*/
#define AMR_DELAY      40  /* Algorithmic delay of the AMR speech codec alone in samples */
#define AMRNS_DELAY    40  /* Algorithmic delay of the AMR speech codec together with the NS solution */

#define AMRNS_CANDIDATE_ACRONYM  "xx"
#if defined(__unix) || defined(__unix__)
#define CMD_FILE_REMOVE          "rm "
#define DATABASE_ROOT            "~paajanen/cprog_c/ObjMeaNS/ns_amr/hlabC"
#define COMMAND_LINE_AMR         "~paajanen/cprog_c/ObjMeaNS/execs/amr_encoder "
#define COMMAND_LINE_AMRNS       "~paajanen/cprog_c/ObjMeaNS/execs/amrns_encoder "
#define COMMAND_LINE_DECODER     "~paajanen/cprog_c/ObjMeaNS/execs/amr_decoder "
#else /* non-unix environment */
#define CMD_FILE_REMOVE          "del "
#define DATABASE_ROOT            "C:\\cprog_c\\ObjMeaNS\\ns_amr\\hlabC"
#define COMMAND_LINE_AMR         "C:\\cprog_c\\ObjMeaNS\\execs\\amr_encoder "
#define COMMAND_LINE_AMRNS       "C:\\cprog_c\\ObjMeaNS\\execs\\amrns_encoder "
#define COMMAND_LINE_DECODER     "C:\\cprog_c\\ObjMeaNS\\execs\\amr_decoder "
#endif /* __unix, __unix__ */


#define CLEAN_EXT                ".vaf"
#define NOISY_EXT                ".pre"
#define AMR_EXT                  ".08m"
#define AMRNS_EXT                ".08k"


#define REPORT_FILENAME          "Results.txt"


/*---------------------------------------------------------------------------
 *                                Types
 *--------------------------------------------------------------------------*/
typedef struct {
    int   NbFr;
    int   Ktot;
    int   Ksph;       
    int   Kspm;  
    int   Kspl;   
    int   Knse;
    float SNRI_h;
    float SNRI_m;
    float SNRI_l;
    float SNRI;
    float NPLR;
} Report;

typedef enum {
   CAR_NOISE_1a = 0,
   CAR_NOISE_1b,
   CAR_NOISE_2a,
   CAR_NOISE_2b,
   STREET_NOISE_3a,
   STREET_NOISE_3b,
   STREET_NOISE_4a,
   STREET_NOISE_4b,
   CAR_NOISE_10b,
   CAR_NOISE_10c,
   NB_CDT
} NoiseType;

#define LAST_CAR                 CAR_NOISE_2b
#define LAST_STREET              STREET_NOISE_4b
#define LAST_AGGREGATE           LAST_STREET

typedef struct {
   NoiseType  noise;
   char      *mode;
   char      *base;
   char      *expNum;
   char      *testLabAcronym;
   char      *candidateAcronym;
   char      *sampleBegString;
   int        firstSample;
   int        lastSample;
   int        sampleDigitNumber;
   char      *cond;
} FileDesc;


/*---------------------------------------------------------------------------
 *                                Functions
 *--------------------------------------------------------------------------*/
Report *Process(int run_mode, char *CleanFilename, char *NoisyFilename,
                char *AmrFilename, char *AmrNsFilename, char *AmrMode);

/*---------------------------------------------------------------------------
 *                                Data
 *--------------------------------------------------------------------------*/
extern FileDesc files[];

#endif
